summaryrefslogtreecommitdiff
path: root/board/volmar
diff options
context:
space:
mode:
authorYu-An Chen <yu-an.chen@quanta.corp-partner.google.com>2022-01-11 19:13:04 +0800
committerCommit Bot <commit-bot@chromium.org>2022-01-12 02:47:05 +0000
commitfc20736a8d82ed5e9132cd0c1a293c26f1d34a7c (patch)
tree78b04228756baf278094e5016ade76e4717e1702 /board/volmar
parente035f5ac951027e49d33a7d3e3a4247ab83c2ab2 (diff)
downloadchrome-ec-fc20736a8d82ed5e9132cd0c1a293c26f1d34a7c.tar.gz
volmar: Change board name
change board name to volmar BUG=b:213127419 BRANCH=none TEST=make BOARD=volmar Signed-off-by: Yu-An Chen <yu-an.chen@quanta.corp-partner.google.com> Change-Id: I8feb8a121c55e21ffef2b091f304c4528f145816 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3379789 Reviewed-by: caveh jalali <caveh@chromium.org> Commit-Queue: caveh jalali <caveh@chromium.org>
Diffstat (limited to 'board/volmar')
-rw-r--r--board/volmar/battery.c2
-rw-r--r--board/volmar/board.h4
-rw-r--r--board/volmar/fw_config.c10
-rw-r--r--board/volmar/fw_config.h14
-rw-r--r--board/volmar/led.c2
-rw-r--r--board/volmar/usbc_config.h2
6 files changed, 17 insertions, 17 deletions
diff --git a/board/volmar/battery.c b/board/volmar/battery.c
index 172365195e..1a675249ed 100644
--- a/board/volmar/battery.c
+++ b/board/volmar/battery.c
@@ -11,7 +11,7 @@
#include "compile_time_macros.h"
#include "gpio.h"
/*
- * Battery info for all Brya battery types. Note that the fields
+ * Battery info for all Volmar battery types. Note that the fields
* start_charging_min/max and charging_min/max are not used for the charger.
* The effective temperature limits are given by discharging_min/max_c.
*
diff --git a/board/volmar/board.h b/board/volmar/board.h
index b9217e32d9..a535838edc 100644
--- a/board/volmar/board.h
+++ b/board/volmar/board.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* Brya board configuration */
+/* Volmar board configuration */
#ifndef __CROS_EC_BOARD_H
#define __CROS_EC_BOARD_H
@@ -11,7 +11,7 @@
#include "compile_time_macros.h"
/*
- * Early brya boards are not set up for vivaldi
+ * Early Volmar boards are not set up for vivaldi
*/
#undef CONFIG_KEYBOARD_VIVALDI
diff --git a/board/volmar/led.c b/board/volmar/led.c
index be2b832237..ac6adfd707 100644
--- a/board/volmar/led.c
+++ b/board/volmar/led.c
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* Brya specific PWM LED settings: there are 2 LEDs on each side of the board,
+/* Volmar specific PWM LED settings: there are 2 LEDs on each side of the board,
* each one can be controlled separately. The LED colors are white or amber,
* and the default behavior is tied to the charging process: both sides are
* amber while charging the battery and white when the battery is charged.
diff --git a/board/volmar/usbc_config.h b/board/volmar/usbc_config.h
index 3a500af9d3..9e9bb5c2a8 100644
--- a/board/volmar/usbc_config.h
+++ b/board/volmar/usbc_config.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* Brya board-specific USB-C configuration */
+/* Volmar board-specific USB-C configuration */
#ifndef __CROS_EC_USBC_CONFIG_H
#define __CROS_EC_USBC_CONFIG_H
diff --git a/board/volmar/fw_config.c b/board/volmar/fw_config.c
index 544f276d25..da56362496 100644
--- a/board/volmar/fw_config.c
+++ b/board/volmar/fw_config.c
@@ -12,20 +12,20 @@
#define CPRINTS(format, args...) cprints(CC_CHIPSET, format, ## args)
-static union brya_cbi_fw_config fw_config;
+static union volmar_cbi_fw_config fw_config;
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
* FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
* initialized.
*/
-static const union brya_cbi_fw_config fw_config_defaults = {
+static const union volmar_cbi_fw_config fw_config_defaults = {
.usb_db = DB_USB3_PS8815,
.kb_bl = KEYBOARD_BACKLIGHT_ENABLED,
};
/****************************************************************************
- * Brya FW_CONFIG access
+ * Volmar FW_CONFIG access
*/
void board_init_fw_config(void)
{
@@ -50,7 +50,7 @@ void board_init_fw_config(void)
}
}
-union brya_cbi_fw_config get_fw_config(void)
+union volmar_cbi_fw_config get_fw_config(void)
{
return fw_config;
}
@@ -12,20 +12,20 @@
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
- * FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
+ * FW_CONFIG defaults for volmar if the CBI.FW_CONFIG data is not
* initialized.
*/
diff --git a/board/volmar/fw_config.h b/board/volmar/fw_config.h
index ed4dbce7d9..b34b8d4b54 100644
--- a/board/volmar/fw_config.h
+++ b/board/volmar/fw_config.h
@@ -3,15 +3,15 @@
* found in the LICENSE file.
*/
-#ifndef __BOARD_BRYA_FW_CONFIG_H_
-#define __BOARD_BRYA_FW_CONFIG_H_
+#ifndef __BOARD_VOLMAR_FW_CONFIG_H_
+#define __BOARD_VOLMAR_FW_CONFIG_H_
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for Brya board.
*
* Source of truth is the project/brya/brya/config.star configuration file.
*/
enum ec_cfg_usb_db_type {
@@ -25,7 +25,7 @@ enum ec_cfg_keyboard_backlight_type {
KEYBOARD_BACKLIGHT_ENABLED = 1
};
-union brya_cbi_fw_config {
+union volmar_cbi_fw_config {
struct {
enum ec_cfg_usb_db_type usb_db : 4;
uint32_t sd_db : 2;
@@ -42,7 +42,7 @@ union brya_cbi_fw_config {
*
* @return the FW_CONFIG for the board.
*/
-union brya_cbi_fw_config get_fw_config(void);
+union volmar_cbi_fw_config get_fw_config(void);
/**
* Get the USB daughter board type from FW_CONFIG.
@@ -51,4 +51,4 @@ union brya_cbi_fw_config get_fw_config(void);
*/
enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void);
-#endif /* __BOARD_BRYA_FW_CONFIG_H_ */
+#endif /* __BOARD_VOLMAR_FW_CONFIG_H_ */
@@ -3,15 +3,15 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for Brya board.
+ * CBI FW_CONFIG layout for Volmar board.
*
@@ -3,15 +3,15 @@
*
- * Source of truth is the project/brya/brya/config.star configuration file.
+ * Source of truth is the project/brya/volmar/config.star configuration file.
*/
enum ec_cfg_usb_db_type {